==> kadu_0.12.3.orig.tar.bz2: kadu-0.12.3/plugins/speech/translations/speech_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="it">
<context>
    <name>@default</name>
    <message>
        <source>Speech</source>
        <translation>Spech</translation>
    </message>
    <message>
        <source>Notifications</source>
        <translation>Notifiche</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Generale</translation>
    </message>
    <message>
        <source>Maximum number of spoken letters</source>
        <translation>Quatntià massima delle lettere pronunciate</translation>
    </message>
    <message>
        <source>Message too long (male)</source>
        <translation>Messaggio troppo lungo (maschio)</translation>
    </message>
    <message>
        <source>Message too long (female)</source>
        <translation>Messaggio tropo lungo (femmina)</translation>
    </message>
    <message>
        <source>Voice</source>
        <translation>Voce</translation>
    </message>
    <message>
        <source>Frequency</source>
        <translation>Frequenza</translation>
    </message>
    <message>
        <source>Base frequency</source>
        <translation>Frequenza di base</translation>
    </message>
    <message>
        <source>Tempo</source>
        <translation>Temp</translation>
    </message>
    <message>
        <source>Melody</source>
        <translation>Melodia</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>Suono</translation>
    </message>
    <message>
        <source>Sound system</source>
        <translation>Sistema suono</translation>
    </message>
    <message>
        <source>aRts</source>
        <translation>aRts</translation>
    </message>
    <message>
        <source>Esd</source>
        <translation>ESD</translation>
    </message>
    <message>
        <source>Dsp</source>
        <translation>DSP</translation>
    </message>
    <message>
        <source>Dsp device</source>
        <translation>Dispositivo DSP</translation>
    </message>
    <message>
        <source>Klatt synthesizer (requires dsp)</source>
        <translation>Syntesi di Klatt (dsp richiesto)</translation>
    </message>
    <message>
        <source>Speech program</source>
        <translation>Speech program</translation>
    </message>
    <message>
        <source>Test</source>
        <translation>Prova</translation>
    </message>
    <message>
        <source>Read a text</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SpeechConfigurationWidget</name>
    <message>
        <source>Male format</source>
        <translation>Formato maschio</translation>
    </message>
    <message>
        <source>Female format</source>
        <translation>Formato femmina</translation>
    </message>
</context>
</TS>

==> kadu_1.3.orig.tar.bz2: kadu-1.3/plugins/speech/translations/speech_it.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="it" version="2.0">
<context>
    <name>@default</name>
    <message>
        <source>Speech</source>
        <translation>Spech</translation>
    </message>
    <message>
        <source>Notifications</source>
        <translation>Notifiche</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Generale</translation>
    </message>
    <message>
        <source>Maximum number of spoken letters</source>
        <translation>Quatntià massima delle lettere pronunciate</translation>
    </message>
    <message>
        <source>Message too long (male)</source>
        <translation>Messaggio troppo lungo (maschio)</translation>
    </message>
    <message>
        <source>Message too long (female)</source>
        <translation>Messaggio tropo lungo (femmina)</translation>
    </message>
    <message>
        <source>Voice</source>
        <translation>Voce</translation>
    </message>
    <message>
        <source>Frequency</source>
        <translation>Frequenza</translation>
    </message>
    <message>
        <source>Base frequency</source>
        <translation>Frequenza di base</translation>
    </message>
    <message>
        <source>Tempo</source>
        <translation>Temp</translation>
    </message>
    <message>
        <source>Melody</source>
        <translation>Melodia</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>Suono</translation>
    </message>
    <message>
        <source>Sound system</source>
        <translation>Sistema suono</translation>
    </message>
    <message>
        <source>aRts</source>
        <translation>aRts</translation>
    </message>
    <message>
        <source>Esd</source>
        <translation>ESD</translation>
    </message>
    <message>
        <source>Dsp</source>
        <translation>DSP</translation>
    </message>
    <message>
        <source>Dsp device</source>
        <translation>Dispositivo DSP</translation>
    </message>
    <message>
        <source>Klatt synthesizer (requires dsp)</source>
        <translation>Syntesi di Klatt (dsp richiesto)</translation>
    </message>
    <message>
        <source>Speech program</source>
        <translation>Speech program</translation>
    </message>
    <message>
        <source>Test</source>
        <translation>Prova</translation>
    </message>
    <message>
        <source>Read a text</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SpeechConfigurationWidget</name>
    <message>
        <source>Male format</source>
        <translation>Formato maschio</translation>
    </message>
    <message>
        <source>Female format</source>
        <translation>Formato femmina</translation>
    </message>
</context>
</TS>
